@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.h,v 1.18 2004/06/03 18:51:32 marco Exp $
+ * $Id$
  */
 
 #ifndef MozDownload_h__
@@ -51,7 +51,6 @@
 #include "ephy-download.h"
 #include "ephy-embed-shell.h"
 
-#include <nsIDownload.h>
 #include <nsIWebProgressListener.h>
 #include <nsIDOMDocument.h>
 #include <nsIURI.h>
@@ -61,6 +60,12 @@
 #include <nsIRequest.h>
 #include <nsIMIMEInfo.h>
 
+#ifdef HAVE_NSITRANSFER_H
+#include <nsITransfer.h>
+#else
+#include <nsIDownload.h>
+#endif
+
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 /* MozDownload
@@ -91,17 +96,31 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceUri
 				  PRInt32 aMaxSize);
 nsresult BuildDownloadPath (const char *defaultFileName, nsILocalFile **_retval);
 
-class MozDownload : public nsIDownload,
+class MozDownload :
+#ifdef HAVE_NSITRANSFER_H
+		    public nsITransfer
+#else
+		    public nsIDownload,
                     public nsIWebProgressListener
+#endif
 {
 public:
         MozDownload();
 	virtual ~MozDownload();
     
 	NS_DECL_ISUPPORTS
-	NS_DECL_NSITRANSFER
-	NS_DECL_NSIDOWNLOAD
 	NS_DECL_NSIWEBPROGRESSLISTENER
+	NS_DECL_NSITRANSFER
+#ifndef HAVE_NSITRANSFER_H
+	NS_DECL_NSIDOWNLOAD
+#endif
+
+#ifdef HAVE_NSITRANSFER_H
+	nsresult GetMIMEInfo (nsIMIMEInfo **aMIMEInfo);
+	nsresult GetTargetFile (nsILocalFile **aFile);
+	nsresult GetSource(nsIURI * *aSource);
+	nsresult GetPercentComplete(PRInt32 *aPercentComplete);
+#endif
 
 	virtual void Cancel();
 	virtual void Pause();
