@@ -20,6 +20,8 @@
    Boston, MA 02111-1307, USA.
 
    Authors: Ramiro Estrugo <ramiro@eazel.com>
+
+   $Id: eel-gconf-extensions.c,v 1.11 2004/04/07 10:38:47 chpe Exp $
 */
 
 #ifdef HAVE_CONFIG_H
@@ -73,22 +75,10 @@ eel_gconf_client_get_global (void)
 gboolean
 eel_gconf_handle_error (GError **error)
 {
-	char *message;
-	static gboolean shown_dialog = FALSE;
-	
 	g_return_val_if_fail (error != NULL, FALSE);
 
 	if (*error != NULL) {
 		g_warning (_("GConf error:\n  %s"), (*error)->message);
-		if (! shown_dialog) {
-			shown_dialog = TRUE;
-
-			message = g_strdup_printf (_("GConf error:\n  %s\n"
-						     "All further errors shown "
-						     "only on terminal"),
-						   (*error)->message);
-			g_free (message);
-		}
 		g_error_free (*error);
 		*error = NULL;
 
