@@ -1,6 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmarks-import.c,v 1.36 2004/08/09 15:19:39 chpe Exp $
+ *  $Id: ephy-bookmarks-import.c,v 1.37.4.1 2004/10/19 17:36:32 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -301,7 +302,8 @@ xbel_parse_folder (EphyBookmarks *eb, xmlTextReaderPtr reader, char *parent_fold
 				}
 				else
 				{
-					folder = g_strconcat (parent_folder, "/",
+					folder = g_strconcat (parent_folder,
+							      BOOKMARKS_HIERARCHY_SEP,
 							      title, NULL);
 				}
 
@@ -416,7 +418,7 @@ xbel_parse_xbel (EphyBookmarks *eb, xmlTextReaderPtr reader)
 			/* shouldn't happen but does anyway :( */
 		}
 		else if (xmlStrEqual (tag, (xmlChar *) "bookmark") && type == XML_READER_TYPE_ELEMENT
-			 && state == STATE_FOLDER)
+			 && state == STATE_XBEL)
 		{
 			EphyNode *node = NULL;
 
@@ -675,7 +677,7 @@ folders_list_to_topic_name (GList *folders)
 
 	for (l = folders->next; l != NULL; l = l->next)
 	{
-		g_string_append (topic, "/");
+		g_string_append (topic, BOOKMARKS_HIERARCHY_SEP);
 		g_string_append (topic, l->data);
 	}
 
