@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history-window.c,v 1.70 2004/07/14 16:44:35 marco Exp $
+ *  $Id: ephy-history-window.c,v 1.71.4.7 2004/12/03 01:26:06 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -166,7 +166,7 @@ static GtkActionEntry ephy_history_ui_entries [] = {
 	{ "OpenInWindow", GTK_STOCK_OPEN, N_("_Open in New Window"), "<control>O",
 	  N_("Open the selected history link in a new window"),
 	  G_CALLBACK (cmd_open_bookmarks_in_browser) },
-	{ "OpenInTab", NULL, N_("Open in New _Tab"), "<shift><control>O",
+	{ "OpenInTab", STOCK_NEW_TAB, N_("Open in New _Tab"), "<shift><control>O",
 	  N_("Open the selected history link in a new tab"),
 	  G_CALLBACK (cmd_open_bookmarks_in_tabs) },
 	{ "Delete", GTK_STOCK_DELETE, N_("_Delete"), NULL,
@@ -834,7 +834,7 @@ remove_focus_monitor (EphyHistoryWindow *editor, GtkWidget *widget)
                                              editor);
 }
 
-static void
+static gboolean
 ephy_history_window_show_popup_cb (GtkWidget *view,
 				   EphyHistoryWindow *editor)
 {
@@ -842,8 +842,9 @@ ephy_history_window_show_popup_cb (GtkWidget *view,
 
 	widget = gtk_ui_manager_get_widget (editor->priv->ui_merge,
 					    "/EphyHistoryWindowPopup");
-	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
-			gtk_get_current_event_time ());
+	ephy_node_view_popup (EPHY_NODE_VIEW (view), widget);
+
+	return TRUE;
 }
 
 static gboolean
@@ -877,38 +878,57 @@ add_by_site_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level
 		 level);
 }
 
-#define SEC_PER_DAY (60 * 60 * 24)
-
 static void
-add_by_date_filter (EphyHistoryWindow *editor, EphyNodeFilter *filter, int level,
+add_by_date_filter (EphyHistoryWindow *editor,
+		    EphyNodeFilter *filter,
+		    int level,
 		    EphyNode *equals)
 {
-	GTime now, cmp_time, days;
-	int time_range;
-
-	/* FIXME this is probably wrong for timezones */
+	time_t now, midnight, cmp_time = 0;
+	struct tm btime;
+	int time_range, days = 0;
 
 	time_range = gtk_combo_box_get_active
 		(GTK_COMBO_BOX (editor->priv->time_combo));
 
+	/* no need to setup a new filter */
+	if (time_range == TIME_EVER) return;
+
 	now = time (NULL);
-	days = now / SEC_PER_DAY;
+	if (localtime_r (&now, &btime) == NULL) return;
+
+	/* get start of day */
+	btime.tm_sec = 0;
+	btime.tm_min = 0;
+	btime.tm_hour = 0;
+	midnight = mktime (&btime);
 
 	switch (time_range)
 	{
-		case TIME_EVER:
-			return;
-		case TIME_TODAY:
-			break;
-		case TIME_LAST_TWO_DAYS:
-			days -= 1;
-			break;
 		case TIME_LAST_THREE_DAYS:
-			days -= 2;
+			days++;
+			/* fall-through */
+		case TIME_LAST_TWO_DAYS:
+			days++;
+			/* fall-through */
+		case TIME_TODAY:
+			cmp_time = midnight;
+			break;
+		default:
+			g_return_if_reached ();
 			break;
 	}
 
-	cmp_time = days * SEC_PER_DAY;
+	while (--days >= 0)
+	{
+		/* subtract 1 day */
+		cmp_time -= 43200;
+		localtime_r (&cmp_time, &btime);
+		btime.tm_sec = 0;
+		btime.tm_min = 0;
+		btime.tm_hour = 0;
+		cmp_time = mktime (&btime);
+	}
 
 	ephy_node_filter_add_expression
 		(filter, ephy_node_filter_expression_new
@@ -1204,6 +1224,7 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 				       GTK_ICON_SIZE_MENU,
 				       NULL);
 	gtk_window_set_icon (GTK_WINDOW(editor), icon);
+	g_object_unref (icon);
 
 	g_signal_connect (editor, "delete_event",
 			  G_CALLBACK (delete_event_cb), NULL);
@@ -1350,7 +1371,7 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 			  G_CALLBACK (ephy_history_window_node_activated_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (pages_view),
-			  "show_popup",
+			  "popup_menu",
 			  G_CALLBACK (ephy_history_window_show_popup_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (pages_view),
@@ -1364,7 +1385,7 @@ ephy_history_window_construct (EphyHistoryWindow *editor)
 
 	ephy_state_add_window (GTK_WIDGET (editor),
 			       "history_window",
-		               450, 400,
+		               450, 400, FALSE,
 			       EPHY_STATE_WINDOW_SAVE_SIZE | EPHY_STATE_WINDOW_SAVE_POSITION);
 	ephy_state_add_paned  (GTK_WIDGET (hpaned),
 			       "history_paned",
@@ -1505,4 +1526,3 @@ ephy_history_window_dispose (GObject *object)
 
 	G_OBJECT_CLASS (parent_class)->dispose (object);
 }
-
