@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.20 2004/08/06 14:34:07 chpe Exp $
+ *  $Id: ephy-session.c,v 1.20.4.5 2004/12/03 16:00:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -38,7 +38,9 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
+#include <errno.h>
 #include <string.h>
+#include <stdlib.h>
 #include <gtk/gtkdialog.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtklabel.h>
@@ -284,6 +286,8 @@ ephy_session_dispose (GObject *object)
 	LOG ("EphySession disposing")
 
 	session_delete (session, SESSION_CRASHED);
+
+	parent_class->dispose (object);
 }
 
 static void
@@ -445,7 +449,7 @@ ephy_session_autoresume (EphySession *session)
 
 	LOG ("ephy_session_autoresume")
 
-	if (session->priv->windows != NULL) return FALSE;
+	if (session->priv->windows != NULL || session->priv->tool_windows != NULL) return FALSE;
 
 	if (session->priv->resume_dialog)
 	{
@@ -476,6 +480,11 @@ ephy_session_close (EphySession *session)
 
 	LOG ("ephy_session_close")
 
+	/* we have to ref the shell or else we may get finalised between
+	 * destroying the windows and destroying the tool windows
+	 */
+	g_object_ref (ephy_shell);
+
 	windows	= ephy_session_get_windows (session);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);
@@ -483,6 +492,8 @@ ephy_session_close (EphySession *session)
 	windows = g_list_copy (session->priv->tool_windows);
 	g_list_foreach (windows, (GFunc) gtk_widget_destroy, NULL);
 	g_list_free (windows);	
+
+	g_object_unref (ephy_shell);
 }
 
 static int
@@ -510,7 +521,7 @@ static int
 write_window_geometry (xmlTextWriterPtr writer,
 		       GtkWindow *window)
 {
-	int x = 0, y = 0, width = 0, height = 0;
+	int x = 0, y = 0, width = -1, height = -1;
 	int ret;
 
 	/* get window geometry */
@@ -709,6 +720,55 @@ parse_embed (xmlNodePtr child, EphyWindow *window)
 	}
 }
 
+static gboolean
+int_from_string (const char *string,
+		 int *retval)
+{
+	char *tail = NULL;
+	long int val;
+	gboolean success = FALSE;
+
+	errno = 0;
+	val = strtol (string, &tail, 0);
+
+	if (errno == 0 && tail != NULL && tail[0] == '\0')
+	{
+		*retval = (int) val;
+		success = TRUE;
+	}
+
+	return success;
+}
+
+static void
+restore_geometry (GtkWindow *window,
+		  xmlNodePtr node)
+{
+	xmlChar *tmp;
+	int x = 0, y = 0, width = -1, height = -1;
+	gboolean success = TRUE;
+
+	g_return_if_fail (window != NULL);
+
+	tmp = xmlGetProp (node, (xmlChar *) "x");
+	success &= int_from_string ((char *) tmp, &x);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "y");
+	success &= int_from_string ((char *) tmp, &y);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "width");
+	success &= int_from_string ((char *) tmp, &width);
+	xmlFree (tmp);
+	tmp = xmlGetProp (node, (xmlChar *) "height");
+	success &= int_from_string ((char *) tmp, &height);
+	xmlFree (tmp);
+
+	if (success)
+	{
+		gtk_window_move (window, x, y);
+		gtk_window_set_default_size (window, width, height);
+	}
+}
 /*
  * ephy_session_load:
  * @session: a #EphySession
@@ -749,7 +809,9 @@ ephy_session_load (EphySession *session,
 		if (xmlStrEqual (child->name, (const xmlChar *) "window"))
 		{
 			widget = GTK_WIDGET (ephy_window_new ());
+			restore_geometry (GTK_WINDOW (widget), child);
 			parse_embed (child->children, EPHY_WINDOW (widget));
+			gtk_window_present (GTK_WINDOW (widget));
 		}
 		else if (xmlStrEqual (child->name, (const xmlChar *) "toolwindow"))
 		{
@@ -771,29 +833,9 @@ ephy_session_load (EphySession *session,
 					widget = ephy_shell_get_history_window (ephy_shell);
 				}
 			}
-		}
 
-		if (widget)
-		{
-			xmlChar *tmp;
-			gulong x = 0, y = 0, width = 0, height = 0;
-
-			tmp = xmlGetProp (child, (xmlChar *) "x");
-			ephy_string_to_int ((char *) tmp, &x);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, (xmlChar *) "y");
-			ephy_string_to_int ((char *) tmp, &y);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, (xmlChar *) "width");
-			ephy_string_to_int ((char *) tmp, &width);
-			xmlFree (tmp);
-			tmp = xmlGetProp (child, (xmlChar *) "height");
-			ephy_string_to_int ((char *) tmp, &height);
-			xmlFree (tmp);
-			gtk_window_move (GTK_WINDOW (widget), x, y);
-			gtk_window_set_default_size (GTK_WINDOW (widget),
-				                     width, height);
-			gtk_widget_show (widget);
+			restore_geometry (GTK_WINDOW (widget), child);
+			gtk_window_present (GTK_WINDOW (widget));
 		}
 
 		child = child->next;
